VmoWriter

Struct VmoWriter 

pub struct VmoWriter { /* private fields */ }

Implementations

Source

impl VmoWriter

pub fn new(size: u64) -> Result<Self, Status>

Creates a new VmoWriter backed by a VMO of size bytes.

pub fn into_vmo(self) -> Vmo

Consumes the writer, returning the underlying VMO.

The inner VMO is guaranteed to be the size given to VmoWriter::new, but its stream size is set to the amount of bytes written to it via the DataWriter implementation.